# EvDiscount

## Installation

Simply add EvDiscount to the `install.php` file within the Config directory and run `Console/cake installer core` once you have added all the other plugins you will need.

If this has already been run, simply run `Console/cake installer plugin EvDiscount`.

The installer will automatically setup the database tables and create a link within the admin menu to create discount codes.

## How it works

The discount plugin currently works based on the events system to trigger when a valid discount code has been added. If using within a standard E-Commerce setup everything is already in place, however if used outside of this some setup work will be needed.

Discount codes can be created at a fixed rate or a percentage amount, restrictions on the number of redemptions is currently **not implemented**, it was planned that this would use `EvInventory` functionality to manage this but never got round to it.

The cookie is stored against the basket in the `ev_basket_basket_data` table under the name `discount_code`. It is added by the basket plugin to this table when the event `EvDiscount.Component.DiscountCodes.codeAdded` is fired.

The contents of basket_data are transferred to the order so a record of the discount code is kept.

Upon `EvCheckout.Controller.Order.success` the discount code uses is incremented.

To do the discount calculations it uses the PriceModifier library https://github.com/EvolutedNewMedia/pricemodifier

## Setup

Once installer has run, simply log into the admin to create any discount codes needed for the site.

Then within the templates, echo out the element that is bundled with `EvDiscount` to add a discount add form to the page.

	<?=$this->element('EvDiscount.Discounts/form')?>

If using outside of the standard EvCommerce setup, you will then need to create an Event listener to listen for `EvDiscount.Component.DiscountCodes.codeAdded`. This event is triggered when a valid code is added, within this listener you should then apply the discount code to your items.

Within `EvBasket` is the listener for the basket plugin that applies the discount code to a customers basket so this can be used as a rough guide.


If used in a custom scenario, you will also need to make sure any discount cookies are cleared upon checkout or purchase of the discounted items.

### Multi-Currency Support
As of version 2.3.2.0, EvDiscount uses multi-currency support as standard. This will pull in EvCurrency which is needed to store/manage currency records.

Each discount code can be assigned to a currency code, and will only work for that one currency code.

## Events

### EvDiscount.Component.DiscountCodes.codeAdded

When a discount code has been successfully validated, this event is triggered. Your code will need to listen for this event and then apply as needed.

EvBasket comes with this listener built in if EvDiscount is detected, this listener will take the code and check any code restrictions are met (correct protects are in the basket) and that the min order is met.

#### Parameters

* `code` - The actual code used
* `data` - Full data array of the code and code restrictions
